package VMOMI::ClusterInfraUpdateHaConfigInfoBehaviorType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
